"use client";
import FormButtons from "@/components/simulation/common/form-buttons";
import Sidebar from "@/components/simulation/common/sidebar";
import { ImageBaseUrl } from "@/configs/api";
import { selectPoolComponents } from "@/servers/actions/pool-request-action";
import { usePoolRequestInfo } from "@/servers/data/use-pool-request-info";
import { useProduct } from "@/servers/data/use-product";
import { useTranslations } from "next-intl";
import dynamic from "next/dynamic";
import { useRouter, useSearchParams } from "next/navigation";
import React, { useState, useTransition } from "react";
import { toast } from "sonner";
const Scene = dynamic(() => import("@/components/swimming-pool/scene"));


const DefaultSelect = { pool: 1, showWater: true, floor: 1, ladder: 0, waterfall: 0, jacuzzi: 0, lamp: 0, selectedTile: null, selectedLadder: null, selectedLight: null };

export default function PoolLadders() {
	const t = useTranslations();
	const router = useRouter();
	const searchParams = useSearchParams();
	const [showItem, setShowItem] = useState<any>(DefaultSelect);
	const [isPending, startTransition] = useTransition();

	// Fetch ladders products
	const { products: lightsProducts, isLoading } = useProduct({ product_type: "lighting" });
	const { poolRequestInfo } = usePoolRequestInfo();

	// Update showItem based on URL parameters
	React.useEffect(() => {
		const pool = searchParams.get("pool");
		const tile = searchParams.get("tile");
		const ladder = searchParams.get("ladder");

		if (pool) {
			setShowItem((prev: typeof DefaultSelect) => ({ ...prev, pool: parseInt(pool) }));
		}

		if (tile) {
			setShowItem((prev: typeof DefaultSelect) => ({ ...prev, selectedTile: { id: parseInt(tile), texture: poolRequestInfo?.data?.tiles?.[0]?.tile?.texture, model_3d: poolRequestInfo?.data?.tiles?.[0]?.tile?.model_3d } }));
		}

		if (ladder) {
			const _ladder = poolRequestInfo?.components?.find((product: any) => product?.type === "ladder");
			console.log("ladder: ", _ladder);
			setShowItem((prev: typeof DefaultSelect) => ({ ...prev, selectedLadder: { id: parseInt(ladder), texture: _ladder?.product?.texture, model_3d: _ladder?.product?.model_3d } }));
		}
	}, [searchParams, poolRequestInfo]);

	React.useEffect(() => {
		if (lightsProducts?.data?.length > 0) {
			setShowItem((prev: typeof DefaultSelect) => ({ ...prev, selectedLight: { id: lightsProducts?.data[0]?.id, texture: lightsProducts?.data[0]?.texture, model_3d: lightsProducts?.data[0]?.model_3d } }));
		}
	}, [lightsProducts]);

	const _lights: any = React.useMemo(() => ({
		title: t("Type of Lights"),
		path: "light",
		images: lightsProducts?.data?.map((product: any) => ({
			src: ImageBaseUrl + product?.images?.[0]?.image_path,
			alt: product?.name_en,
			data: {
				floor: product?.id,
				selectedLight: {
					id: product?.id,
					texture: product?.texture,
					name: product?.name_en,
					model_3d: product?.model_3d
				}
			}
		})) || [],
		position: {
			position: { x: -0.8631814120906298, y: 0.7461551214398308, z: 0.027721804571655614 },
			target: { x: 0.7388833062151203, y: -0.6461891677949362, z: -0.19102622652688483 }
		}

	}), [t, lightsProducts]);

	console.log("showItem", showItem);
	const handleNextPage = async () => {
		if (showItem.selectedLight?.id) {
			const response = await selectPoolComponents({ product_id: showItem.selectedLight?.id, type: "lighting" });
			console.log("response: ", response);
			if (!response.success) {
				toast.error(response.message);
			}
		}

		startTransition(() => {
			router.push(`/simulation-program/pool-waterfalls?pool=${showItem.pool}&tile=${showItem.selectedTile?.id}&ladder=${showItem.selectedLadder?.id}&light=${showItem.selectedLight?.id}` as any);
		});
	};

	return (
		<div className="h-screen w-full start-bg">
			<div className="flex h-full">
				<div className="w-full flex items-center justify-center">
					{showItem.selectedLight?.id && <FormButtons
						onPrevious={() => router.back()}
						onNext={handleNextPage}
						isPending={isPending}
					/>}
					<Scene showItem={showItem} cameraSetting={_lights?.position} />
					<Sidebar
						title={_lights?.title}
						images={_lights?.images}
						setShowItem={setShowItem}
						showItem={showItem}
						isLoading={isLoading}
					/>
				</div>
			</div>
		</div>
	);
}
